@@ -6,7 +6,7 @@ from typing import Any, Dict, Optional, Union
 
 import numpy as np
 import pandas as pd
-import yaml
+from ipywidgets.widgets.widget_box import VBox
 from tqdm.auto import tqdm
 from typeguard import typechecked
 from visions import VisionsTypeset
@@ -24,7 +24,6 @@ from pandas_profiling.model.summarizer import (
 from pandas_profiling.model.typeset import ProfilingTypeSet
 from pandas_profiling.report import get_report_structure
 from pandas_profiling.report.presentation.core import Root
-from pandas_profiling.report.presentation.core.renderable import Renderable
 from pandas_profiling.report.presentation.flavours.html.templates import (
     create_html_assets,
 )
@@ -96,10 +95,7 @@ class ProfileReport(SerializeReport, ExpectationsReport):
             if not config_file:
                 config_file = get_config("config_minimal.yaml")
 
-            with open(config_file) as f:
-                data = yaml.safe_load(f)
-
-            report_config = Settings().parse_obj(data)
+            report_config = Settings().from_file(config_file)
         else:
             report_config = Settings()
 
@@ -238,7 +234,7 @@ class ProfileReport(SerializeReport, ExpectationsReport):
         return self._json
 
     @property
-    def widgets(self) -> Renderable:
+    def widgets(self) -> VBox:
         if (
             isinstance(self.description_set["table"]["n"], list)
             and len(self.description_set["table"]["n"]) > 1
@@ -361,7 +357,7 @@ class ProfileReport(SerializeReport, ExpectationsReport):
             pbar.update()
         return html
 
-    def _render_widgets(self) -> Renderable:
+    def _render_widgets(self) -> VBox:
         from pandas_profiling.report.presentation.flavours import WidgetReport
 
         report = self.report
@@ -473,20 +469,23 @@ class ProfileReport(SerializeReport, ExpectationsReport):
         """Override so that Jupyter Notebook does not print the object."""
         return ""
 
-    def compare(self, other: "ProfileReport") -> "ProfileReport":
+    def compare(
+        self, other: "ProfileReport", config: Optional[Settings] = None
+    ) -> "ProfileReport":
         """Compare this report with another ProfileReport
         Alias for:
         ```
-        pandas_profiling.compare([report1, report2], _labels=[report1.config.title, report2.config.title]
+        pandas_profiling.compare([report1, report2], config=config)
         ```
         See `pandas_profiling.compare` for details.
 
         Args:
             other: the ProfileReport to compare to
+            config: the settings object for the merged ProfileReport. If `None`, uses the caller's config
 
         Returns:
             Comparison ProfileReport
         """
         from pandas_profiling.compare_reports import compare
 
-        return compare([self, other])
+        return compare([self, other], config if config is not None else self.config)
