@@ -1,5 +1,6 @@
 from typing import Any, Callable
 
+from pandas_profiling.config import Style
 from pandas_profiling.report.presentation.core.item_renderer import ItemRenderer
 from pandas_profiling.report.presentation.core.renderable import Renderable
 
@@ -9,9 +10,14 @@ class Root(ItemRenderer):
     Wrapper for the report.
     """
 
-    def __init__(self, name: str, body: Renderable, footer: Renderable, **kwargs):
+    def __init__(
+        self, name: str, body: Renderable, footer: Renderable, style: Style, **kwargs
+    ):
         super().__init__(
-            "report", {"body": body, "footer": footer}, name=name, **kwargs
+            "report",
+            {"body": body, "footer": footer, "style": style},
+            name=name,
+            **kwargs
         )
 
     def __repr__(self) -> str:
